function [sys,x0] = reator(t,x,u,flag,U,A,DeltaH,ro,Cp,E,R,k0)
%
% Simula um reator CSTR (mistura perfeita) no qual se conduz uma 
% reao exotrmica (A->B), resfriado por serpentina
%
% U      = 150     BTU/(h.ft2.R), coeficiente de troca trmica
% A      = 250     ft2,           rea de troca trmica
% DeltaH = -30000  BTU/lbm,       calor de reao
% ro     = 50      lb/ft3,        densidade
% Cp     = 0.75    BTU/(lbm.R),   calor especfico
% E      = 30000   BTU/lbm,       energia de ativao
% R      = 1.99    BTU/(lbm.R),   constante dos gases
% k0     = 7.08e10 1/h,           termo pr-exponencial da constante de reao
%
switch flag
   
   case 0 % Dimensiona o sistema e inicializa os estados
      
      % sys=[estados,0,sadas,entradas,0,0]
      sys = [3,0,3,5,0,0];
      % Condies iniciais
      ca  = 0.1315;                %lbm/ft3, concentrao inicial no reator
      T   = 584.4115;              %R,       temperatura do reator
      V   = 200;                   %ft3,     volume do reator
      x0  = [ca T V]';
      
   case 1 % Calcula as derivadas
      
      % Atualiza entradas
      cai = u(1);                  %lbm/ft3, concentrao da alimentao=0.5;
      Fi  = u(2);                  %ft3/hr, vazo de alimentao=40
      F   = u(3);                  %vazo de retirada=40
      Tc  = u(4);                  %R, temperatura do fluido de refrigerao=594.6
      Ti  = u(5);                  %R, temperatura da alimentao=530
      % Clculo das derivadas

      Ca = x(1);
      T  = x(2);
      V  = x(3);

      k  = k0*exp(-E/(R*T));

      dCa = (Fi*(cai-Ca)/V) - k*Ca;
      dV  = Fi-F;
      dT  = (Fi*Cp*ro*(Ti-T) + DeltaH*k*Ca*V - U*A*(T-Tc)) /(V*ro*Cp);

      sys = [dCa; dT; dV];
      
      
   case 3 % Calcula as sadas

   	sys = [x(1) x(2) x(3)];

   otherwise

   	sys = [];

end
